Obtaining and Using ORDF
========================

It must be emphasised that this is software in the early stages of
development. It is not guaranteed to be stable or fit for any purpose.

Also please mind that it is distributed under the terms of the 
`GNU Affero GPL Version 3`_ which is included in the source distribution.

Mercurial Repositories
----------------------

    * http://knowledgeforge.net/pdw/ordf (primary)
    * http://bitbucket.org/ww/ordf (mirror)

Applications using ORDF
-----------------------

    * http://knowledgeforge.net/pdw/openbiblio (pylons application)

Getting Help
------------

    :trac: trouble ticketing at http://knowledgeforge.net/pdw/trac
    :irc: server: *irc.oftc.net* channel: *#okfn*

.. _GNU Affero GPL Version 3: http://www.gnu.org/licenses/agpl-3.0.html
